﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Data.Odbc;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace SaveImage
{
    public partial class Form1 : Form
    {
        #region Variables

        OdbcConnection myConnection;
        const string DocumentTable = "dcdocument2";
        DataTable myTable;

        #endregion Variables

        #region Init

        public Form1()
        {
            InitializeComponent();

            myConnection = new OdbcConnection();

            myConnection.ConnectionString = "DRIVER={DBISAM 4 ODBC Driver};";
            myConnection.ConnectionString += "ConnectionType=Local;";
            myConnection.ConnectionString += "CatalogName=" + Path.GetDirectoryName(Application.ExecutablePath) + ";";

            myConnection.Open();
            
            UpdateGrid();
        }

        
        private void Form1_FormClosed(object sender, FormClosedEventArgs e)
        {
            myConnection.Close();
        }

        #endregion Init

        #region Form Display

        private void UpdateGrid()
        {
            using (OdbcCommand myCommand = new OdbcCommand("", myConnection))
            {
                using (OdbcDataAdapter myDA = new OdbcDataAdapter(myCommand))
                {
                    using (DataSet myDS = new DataSet())
                    {
                        myCommand.CommandText = "SELECT ID,Name,DocumentMemo,DocumentImage FROM " + DocumentTable;

                        myDA.Fill(myDS, DocumentTable);
                        myTable = myDS.Tables[DocumentTable];

                        Grid.DataSource = myTable;
                    }
                }
            }
        }

        #endregion Form Display

        #region Index Buttons

        private void SelectImageButton_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
                ImageNameEdit.Text = openFileDialog1.FileName;
        }

        #endregion Index Buttons

        #region Buttons

        private void AddButton_Click(object sender, EventArgs e)
        {
            byte[] imagebytes;
            string imagestring;
            Image Portrait;
            Int32 ID;

            try
            {
                if (!String.IsNullOrEmpty(ImageNameEdit.Text))
                {
                    Portrait = new Bitmap(ImageNameEdit.Text);

                    using (MemoryStream ms = new MemoryStream())
                    {
                        Portrait.Save(ms, Portrait.RawFormat);
                        imagebytes = ms.ToArray();
                        imagestring = Encoding.UTF8.GetString(imagebytes, 0, imagebytes.Length);
                    }

                    ID = myTable.Rows.Count + 1;

                    using (OdbcCommand myCommand = new OdbcCommand("", myConnection))
                    {
                        myCommand.CommandText = "INSERT INTO " + DocumentTable
                            + " (ID,Name,DocumentMemo,DocumentImage) VALUES(?,?,?,?)";

                        myCommand.Parameters.Add("ID", OdbcType.Int);
                        myCommand.Parameters.Add("Name", OdbcType.VarChar, 40);
                        myCommand.Parameters.Add("DocumentMemo", OdbcType.Text);
                        myCommand.Parameters.Add("DocumentImage", OdbcType.Image);

                        myCommand.Parameters["ID"].Value = ID;
                        myCommand.Parameters["Name"].Value = "Test" + ID.ToString();
                        myCommand.Parameters["DocumentMemo"].Value = imagestring;
                        myCommand.Parameters["DocumentImage"].Value = imagebytes;

                        myCommand.ExecuteNonQuery();
                    }

                    UpdateGrid();
                }
                else
                    MessageBox.Show("Image name missing", "Cannot Save", MessageBoxButtons.OK, MessageBoxIcon.Warning);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error Saving", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        #endregion Buttons
    }
}
